| wbstats | R Documentation |
Search and download data from the World Bank Data API. Includes support for mutliple languages, access to annual, quarterly, and monthly data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.