Download an updated list of information regarding countries, indicators, sources, regions, indicator topics, lending types, income levels, and supported languages from the World Bank API
wb_cache(lang)A list containing the following items:
countries: The result of calling wb_countries()
indicators: The result of calling wb_indicators()
sources: The result of calling wb_sources()
topics: The result of calling wb_topics()
regions: The result of calling wb_regions()
income_levels: The result of calling wb_income_levels()
lending_types: The result of calling wb_lending_types()
languages: The result of calling wb_languages()
Language in which to return the results. If lang is unspecified, english is the default. For supported languages see wb_languages(). Possible values of lang are in the iso2c column. A note of warning, not all data returns have support for langauges other than english. If the specific return does not support your requested language by default it will return NA.