View source: R/wb_country_coverage.R
| wb_country_coverage | R Documentation |
Given a indicator available from the World Bank API, this functions returns a pre-computed summary stored on GitHub and not available from the API that shows the percentage of non-missing (non-NA) observations for every country, the year range per country, and the total number of observations per country. This is useful before downloading a dataset.
wb_country_coverage(pattern, country, start_date, end_date, cache)
pattern |
A character string or regular expression (e.g., |
country |
Character vector of country, region, or special value codes for the locations you want to return data for. Permissible values can be found in the countries data frame in wb_cachelist or by running
|
start_date |
Numeric or character. If numeric it must be in |
end_date |
Numeric or character. If numeric it must be in |
cache |
List of data frames returned from |
A data.table with one row per country.
## Not run:
wb_country_coverage("gross domestic product", c("Mexico", "Chile"), 2010, 2020)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.