# NOT RUN {
# can get a new list of available indicators by downloading new cache
# }
# NOT RUN {
fresh_cache <- wb_cache()
# }
# NOT RUN {
fresh_indicators <- fresh_cache$indicators
# }
# NOT RUN {
# or by running the wb_indicators() function directly
# }
# NOT RUN {
fresh_indicators <- wb_indicators()
# }
# NOT RUN {
# fresh indicators but in spanish
# a note of warning, please see the lang parameter description
# }
# NOT RUN {
fresco_indicators <- wb_indicators("es")
# }
# NOT RUN {
# include archived indicators
# see include_archive parameter description
# }
# NOT RUN {
indicators_with_achrive <- wb_indicators(include_archive = TRUE)
# }
Run the code above in your browser using DataLab